package io.metersphere.keycloak.service;

import io.metersphere.keycloak.dto.KeycloakAuthSourceReq;
import io.metersphere.system.domain.AuthSource;
import io.metersphere.system.domain.AuthSourceExample;
import io.metersphere.system.mapper.AuthSourceMapper;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;

import java.nio.charset.StandardCharsets;
import java.util.List;

@Service
public class KeycloakAuthSourceService {
    @Resource
    private AuthSourceMapper authSourceMapper;

    public List<AuthSource> listAllEnable() {
        AuthSourceExample example = new AuthSourceExample();
        example.createCriteria().andEnableEqualTo(Boolean.TRUE);
        return authSourceMapper.selectByExampleWithBLOBs(example);
    }

    public AuthSource getAuthSource(String id) {
        return authSourceMapper.selectByPrimaryKey(id);
    }

    public int createAuthSource(KeycloakAuthSourceReq authSource) {
        AuthSource as = getAuthSource(authSource.getId());
        boolean insert = false;
        if (as == null) {
            as  = new AuthSource();
            insert = true;
        }
        as.setId(authSource.getId());
        as.setEnable(authSource.getEnable());
        as.setCreateTime(insert ? authSource.getCreateTime() : as.getCreateTime());
        as.setUpdateTime(authSource.getUpdateTime());
        as.setDescription(authSource.getDescription());
        as.setName(authSource.getName());
        as.setType(authSource.getType());
        as.setConfiguration(authSource.getConfiguration().getBytes(StandardCharsets.UTF_8));
        return insert ? authSourceMapper.insert(as) : authSourceMapper.updateByPrimaryKeyWithBLOBs(as);
    }
}
